@@ -980,11 +980,11 @@ def priority_cols(df, priority='both', extras=None, drop_cols=None):
     -import pandas as pd
     '''
 
+    DATA_PATH = pkg_resources.resource_filename('HL7reporting', 'supporting/')
+    FILE = pkg_resources.resource_filename('HL7reporting', 'supporting/NSSP_Element_Reader.xlsx')
+    reader = pd.read_excel(FILE)
+
 
-    this_dir, this_filename = os.path.split(__file__)
-    DATA_PATH = os.path.join(this_dir, "supporting", "NSSP_Element_Reader.xlsx")
-    reader = pd.read_excel(DATA_PATH)
-   
     # There is a chance that the user removed priority columns from the input dataframe for their own reasons.
     #     Therefore we only want to look at cases where the input dataframe columns match the reader processed column.
     reader = reader[reader['Processed Column'].isin(df.columns)]
